@@ -397,8 +397,9 @@ class Daemon(GObject.GObject, TimerManager):
 		""" Request settings from syncthing daemon """
 		RESTRequest(self, "system/config", self._syncthing_cb_config, self._syncthing_cb_config_error).start()
 	
-	def _request_folder_data(self, rid):
-		RESTRequest(self, "db/status?folder=%s" % (rid,), self._syncthing_cb_folder_data, self._syncthing_cb_folder_data_failed, rid).start()
+	def _request_folder_data(self, folder_id):
+		id_enc = urllib.quote(folder_id.encode('utf-8'))
+		RESTRequest(self, "db/status?folder=%s" % (id_enc,), self._syncthing_cb_folder_data, self._syncthing_cb_folder_data_failed, folder_id).start()
 	
 	def _request_last_seen(self, *a):
 		""" Request 'last seen' values for all devices """
@@ -1042,7 +1043,7 @@ class RESTRequest(Gio.SocketClient):
 		self._connection = None
 		self._callback_data = callback_data or ()
 		if parent._tls:
-			self.connect("event", self._socket_event)
+			GObject.Object.connect(self, "event", self._socket_event)
 	
 	def _connected(self, _self, results):
 		""" Called after TCP connection is initiated """
@@ -1166,13 +1167,13 @@ class RESTRequest(Gio.SocketClient):
 			code = int(headers[0].split(b" ")[1])
 			if code == 401:
 				self._error(HTTPAuthException(buffer))
-				return
+				return None, None
 			elif code == 404:
 				self._error(HTTPCode(404, "Not found", buffer, headers))
-				return
+				return None, None
 			elif code != 200:
 				self._error(HTTPCode(code, response, buffer, headers))
-				return
+				return None, None
 		except Exception, e:
 			# That probably wasn't HTTP
 			import traceback
@@ -1341,7 +1342,13 @@ class EventPollLoop(RESTRequest):
 	def _resend_request(self):
 		""" Sends another request using same connection """
 		self._chunk_size = -1
-		get_str = b"GET /rest/events?since=%s HTTP/1.1\r\n\r\n" % (self._last_event_id,)
+		get_str = "\r\n".join([
+			"GET /rest/events?since=%s HTTP/1.1" % (self._last_event_id,),
+			"Host: %s" % self._parent._address,
+			(("X-API-Key: %s" % self._parent._api_key) if not self._parent._api_key is None else "X-nothing: x"),
+			"",
+			"",
+			]).encode("utf-8")
 		try:
 			self._connection.get_output_stream().write_all(get_str, None)
 		except Exception, e:
