@@ -5,8 +5,7 @@ Syncthing-GTK - RIBar
 Infobar wrapped in Revealer, for greater justice
 """
 from __future__ import unicode_literals
-from gi.repository import Gtk, GLib, GObject, Pango
-import os
+from gi.repository import Gtk, GLib, GObject
 RevealerClass = None
 if hasattr(Gtk, "Revealer"):
 	RevealerClass = Gtk.Revealer
